@@ -13,13 +13,13 @@ QStringList Utils::getXdgDataDirs()
     }
 
     QStringList results;
-    const auto paths = xdgDataDirsEnv.splitRef(QLatin1Char(':'), Qt::SkipEmptyParts);
+    const auto paths = xdgDataDirsEnv.split(QLatin1Char(':'), Qt::SkipEmptyParts);
     // Normalize paths, skip relative paths
     for (const auto &path : paths) {
-        if (!QDir::isAbsolutePath(path.toString()) || !QDir(path.toString()).exists()) {
+        if (!QDir::isAbsolutePath(path) || !QDir(path).exists()) {
             continue;
         }
-        results.append(path.toString());
+        results.append(path);
     }
 
     return results;
